@@ -24,9 +24,6 @@ double diff_mean(double *vec1, double *vec2, int n) // compute largest absolute
   return diff/n;
   }
 
-void bb(double *lim, double *tol); // in bb.c
-void optim(); 
-
 void Rf_VB_bbs(int *imodel,
   int *steps,
   int *max_iter,
@@ -75,7 +72,10 @@ void Rf_VB_bbs(int *imodel,
   int i, j, d, g, p, l, g1;
   double tmp, tmpsum1, tmpsum2;
   double mu_nought = 0.0;
+  int flag;
+  Rf_params *params;
   params=calloc(1,sizeof(Rf_params));
+  params->flag=&flag; 
   params->MAX_ITER=max_iter;
   params->P_n=P_n;
   params->P_e=P_e;
@@ -141,8 +141,6 @@ void Rf_VB_bbs(int *imodel,
   old_omega2 = calloc(*G, sizeof(double));
   old_lambda = calloc(*G * *N, sizeof(double));
 
-  int flag;
-  params->flag=&flag; 
   /*
   char **V_names = calloc(9, sizeof(char *));
   for (i=0; i<9; i++)
@@ -172,7 +170,6 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
     for (i=0; i<*N; i++)
       { 
       params->i=&samp_nodes[i]; 
-      optim();
       }
     d_vector[0]=diff_max(V_z, old_z, *N * *D);
     } else d_vector[0] = 0.0;
@@ -208,7 +205,7 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
       {
       params->i=&samp_nodes[i];
       lim[0]=1.0e-8; lim[1]=1.0e1;
-      bb(lim, tol);
+      bb(lim, tol, params);
       }
     d_vector[1]=diff_max(V_sigma2, old_sigma2, *N);
     } else d_vector[1] = 0.0;
@@ -281,7 +278,7 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
       {        
       params->g=&samp_groups[g];
       lim[0]=1.0e-8; lim[1]=1.0e1;
-      bb(lim, tol); 
+      bb(lim, tol, params);
       }
     d_vector[5]=diff_max(V_alpha, old_alpha, *G);
     } else d_vector[5] = 0.0;
@@ -296,7 +293,7 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
       {
       params->g=&samp_groups[g];
       lim[0]=1.0e-8; lim[1]=1.0e1;
-      bb(lim, tol);
+      bb(lim, tol, params);
       }
     d_vector[6]=diff_max(V_nu, old_nu, *G);
     } else d_vector[6] = 0.0;
@@ -316,7 +313,7 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
         for (i=0; i<*N; i++)
           {
           params->i=&samp_nodes[i];
-          bb(lim, tol);
+          bb(lim, tol, params);
           }
 /*
 	// FLAG
@@ -350,7 +347,7 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
         {
         params->p=&samp_coeffs_e[p];
         lim[0]=-1.0e2; lim[1]=1.0e2;
-        bb(lim, tol);
+        bb(lim, tol, params);
         }
       tmp=diff_max(V_xi_e, old_xi_e, *P_e);
       d_vector[7]=(tmp>d_vector[7] ? tmp : d_vector[7]);
@@ -367,7 +364,7 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
         {
         params->p=&p;
         lim[0]=1.0e-8; lim[1]=1.0e1;
-        bb(lim, tol); 
+        bb(lim, tol, params); 
         }
       d_vector[8]=diff_max(V_psi2_n, old_psi2_n, *P_n);
       }
@@ -382,7 +379,7 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
         {
         params->p=&samp_coeffs_e[p];
         lim[0]=1.0e-8; lim[1]=1.0e1;
-        bb(lim, tol); 
+        bb(lim, tol, params); 
         }
       tmp=diff_max(V_psi2_e, old_psi2_e, *P_e);
       d_vector[8]=(tmp>d_vector[8] ? tmp : d_vector[8]);
@@ -425,6 +422,5 @@ for (l=0; l<*steps; l++) // number of cycles through the variational algorithm
     free(old_omega2);
     free(old_lambda);
     free(params->dists);
-    free(params);
     return;
     }
